@@ -98,7 +98,7 @@ type coq_object =
   | CoqGlobRef   of Names.GlobRef.t
   | CoqGlobRefExt of Globnames.extended_global_reference
   | CoqImplicit  of Impargs.implicits_list
-  | CoqProfData  of Profile_ltac.treenode
+  | CoqProfData  of Profile_tactic.treenode
   | CoqNotation  of Constrexpr.notation
   | CoqUnparsing of Ppextend.notation_printing_rules * Notation_gram.notation_grammar
   | CoqGoal      of Constr.t               Serapi_goals.reified_goal Serapi_goals.ser_goals
@@ -489,7 +489,7 @@ module QueryUtil = struct
     let cdef = Environ.lookup_constant cr env in
     let cb = Environ.lookup_constant cr env in
     Option.cata (fun (cb,_univs,_uctx) -> [CoqConstr cb] ) []
-      (Global.body_of_constant_body Library.indirect_accessor cb),
+      (Global.body_of_constant_body (Library.indirect_accessor[@warning "-3"]) cb),
     [CoqConstr(type_of_constant cdef)]
 
   let info_of_var env vr =
@@ -534,7 +534,8 @@ module QueryUtil = struct
     let cstr, _ = UnivGen.fresh_global_instance env gr in
     let st = Conv_oracle.get_transp_state (Environ.oracle env) in
     let nassums =
-      Assumptions.assumptions st ~add_opaque:true ~add_transparent:true gr cstr in
+      Assumptions.assumptions (Library.indirect_accessor[@warning "-3"])
+        st ~add_opaque:true ~add_transparent:true gr cstr in
     Serapi_assumptions.build env nassums
 
   (* This should be moved Coq upstream *)
@@ -568,7 +569,7 @@ let obj_query ~doc ~pstate ~env (opt : query_opt) (cmd : query_cmd) : coq_object
   | Tactics prefix -> List.map (fun (i,t) -> CoqTactic(i,t)) @@ QueryUtil.query_tactics prefix
   | Locate  id     -> List.map (fun qid -> CoqQualId qid) @@ QueryUtil.locate id
   | Implicits id   -> List.map (fun ii -> CoqImplicit ii ) @@ QueryUtil.implicits id
-  | ProfileData    -> [CoqProfData (Profile_ltac.get_local_profiling_results ())]
+  | ProfileData    -> [CoqProfData (Profile_tactic.get_local_profiling_results ())]
   | Proof          -> QueryUtil.get_proof ~pstate
   | Unparsing ntn  -> (* Unfortunately this will produce an anomaly if the notation is not found...
                        * To keep protocol promises we need to special wrap it.
@@ -583,7 +584,7 @@ let obj_query ~doc ~pstate ~env (opt : query_opt) (cmd : query_cmd) : coq_object
   | TypeOf id      -> snd (QueryUtil.info_of_id env id)
   | Search         -> [CoqString "Not Implemented"]
   (* XXX: should set printing options in all queries *)
-  | Vernac q       -> let pa = Pcoq.Parsable.make (Ser_stream.of_string q) in
+  | Vernac q       -> let pa = Pcoq.Parsable.make (Gramlib.Stream.of_string q) in
                       Stm.query ~doc ~at:opt.sid ~route:opt.route pa; []
   (* XXX: Should set the proper sid state *)
   | Env            -> [CoqEnv env]
@@ -618,8 +619,8 @@ let proof_state_of_st m = match m with
   | _ -> None
 
 let parsing_state_of_st m = match m with
-  | Stm.Valid (Some { Vernacstate.synterp = { parsing; _ }; _} ) ->
-    Some parsing
+  | Stm.Valid (Some { Vernacstate.synterp; _} ) ->
+    Some (Vernacstate.Synterp.parsing synterp)
   | _ -> None
 
 let context_of_st m = match m with
@@ -699,12 +700,13 @@ module ControlUtil = struct
     parsing_state_of_st (Stm.state_of_id ~doc ontop)
     |> Option.map (fun pstate ->
         let entry = Pcoq.Constr.lconstr in
-        let pa = Pcoq.Parsable.make (Ser_stream.of_string str) in
-        Vernacstate.Parser.parse pstate entry pa)
+        let pa = Pcoq.Parsable.make (Gramlib.Stream.of_string str) in
+        Pcoq.unfreeze pstate;
+        Pcoq.Entry.parse entry pa)
 
   let parse_sentence ~doc ~ontop sent =
     let ontop = Extra.value ontop ~default:(Stm.get_current_state ~doc) in
-    let pa = Pcoq.Parsable.make (Ser_stream.of_string sent) in
+    let pa = Pcoq.Parsable.make (Gramlib.Stream.of_string sent) in
     let entry = Pvernac.main_entry in
     Stm.parse_sentence ~doc ontop ~entry pa
 
@@ -717,7 +719,7 @@ module ControlUtil = struct
   exception End_of_input
 
   let add_sentences ~doc opts sent =
-    let pa = Pcoq.Parsable.make (Ser_stream.of_string sent) in
+    let pa = Pcoq.Parsable.make (Gramlib.Stream.of_string sent) in
     let i   = ref 1                    in
     let acc = ref []                   in
     let stt = ref (Extra.value opts.ontop ~default:(Stm.get_current_state ~doc)) in
@@ -942,7 +944,7 @@ let exec_cmd (st : State.t) (cmd : cmd) : answer_kind list * State.t =
   | Tokenize input ->
     let st = CLexer.Lexer.State.get () in
     begin try
-        let istr = Ser_stream.of_string input in
+        let istr = Gramlib.Stream.of_string input in
         let lex = CLexer.Lexer.tok_func istr in
         CLexer.Lexer.State.set st;
         let objs = Extra.stream_tok 0 [] lex in
